@@ -8,7 +8,7 @@ import pandas as pd
 
 def version():
     """
-    * 2021/2/21
+    * 2021/2/22
 
     # 党史项目结束, 海南项目开始
 
@@ -23,8 +23,11 @@ def version():
         - 增加`AliasField`绑定字段方法
         - 按年份分布的统计方法`get_df_by_freq_and_year`
         - 修复distinct_field_ls和order_type_ls的冲突
+        - BaseListView中, 加入'pk'作为默认过滤字段
+        - template调整`simpleui_change_list_actions.html`样式
+        - 新增`only_get_distinct_field`功能
     """
-    v = "2.1.5"     # 正式版: 2.1.4
+    v = "2.1.6"     # 正式版: 2.1.5
     return v
 
 
